from .settings import WITH_SELENIUM
import unittest
from django.test import LiveServerTestCase


@unittest.skipUnless(WITH_SELENIUM, "no --with-selenium flag")
class SeleniumTestCase(LiveServerTestCase):
    pass



from discover_runner import DiscoverRunner
import unittest
from teamcity import is_running_under_teamcity
from teamcity.unittestpy import TeamcityTestRunner
import settings


class DiscoverTeamcityRunner(DiscoverRunner):
    def __init__(self, *args, **kwargs):

        if kwargs['with_selenium']:
            settings.WITH_SELENIUM = True
        super(DiscoverTeamcityRunner, self).__init__(*args, **kwargs)

    def run_suite(self, suite, **kwargs):
        if is_running_under_teamcity():
            runner = TeamcityTestRunner
        else:
            runner = unittest.TextTestRunner
            return runner(verbosity=self.verbosity,
                          failfast=self.failfast,
                          ).run(suite)
    




from setuptools import setup, find_packages

setup(name='django-teamcity',
      version='0.1',
      platforms=["any"],
      description="send test result to TeamCity and provide Selenium support",
      keywords='unittest teamcity test jetbrains django',
      author='Anton Ermak',
      author_email='Rayman.k26@gmail.com',
      license='BSD',
      packages = find_packages(),
      url="https://bitbucket.org/raymank26/django-teamcity",
      install_requires=[
          "django<1.6",
          "django-discover-runner",
          "teamcity-messages",
      ]
      )



from django.core.management.commands.test import Command as TestCommand
import os
from optparse import make_option
import sys

class Command(TestCommand):
    option_list = TestCommand.option_list + (
        make_option('--with-selenium',
                    action='store_true', dest='with_selenium', default=None,
                    help='Set this option to enable test only for SeleniumTestCase subclass'
                    ),)

    def handle(self, *test_labels, **options):
        from django.conf import settings
        from django.test.utils import get_runner

        TestRunner = get_runner(settings, options.get('testrunner'))
 
        options['verbosity'] = int(options.get('verbosity'))

        if options.get('liveserver') is not None:
            os.environ['DJANGO_LIVE_TEST_SERVER_ADDRESS'] = options['liveserver']
            del options['liveserver']

        test_runner = TestRunner(**options)
        failures = test_runner.run_tests(test_labels)

        if failures:
            sys.exit(bool(failures))
